document.addEventListener('DOMContentLoaded', function () {
  document.getElementById('button').addEventListener('click', function () {
    const ariaLabelDiv = document.getElementById('ariaLabel');
    ariaLabelDiv.style.display = 'block'; 

    chrome.tabs.query({ active: true, currentWindow: true }, function (tabs) {
      chrome.scripting.executeScript({
        target: { tabId: tabs[0].id },
        function: getAriaLabel
      }, (results) => {
        if (results && results[0]) {
          const ariaLabels = results[0].result;
          
          // ユーザーが選択した日付を取得
          const selectedDate = document.getElementById('selectDate').value;
          const { weekData, totalTime } = getLastWeekStudyData(ariaLabels, selectedDate);
          const weekSummary = formatWeekData(weekData);
          
          ariaLabelDiv.innerHTML = weekSummary.replace(/\n/g, '<br>') + `<br><span>合計時間: ${totalTime}時間</span>`;
        }
      });
    });
  });
});


function getAriaLabel() {
  const elements = document.evaluate(
    '/html/body/main/div/div[2]/div[3]/div[2]/div[2]/div[2]/div', 
    document, 
    null, 
    XPathResult.ORDERED_NODE_SNAPSHOT_TYPE, 
    null
  );

  const ariaLabels = [];

  for (let i = 0; i < elements.snapshotLength; i++) {
    const element = elements.snapshotItem(i);
    const ariaLabel = element.getAttribute('aria-label');
    if (ariaLabel) {
      ariaLabels.push(ariaLabel);
    }
  }

  return ariaLabels.length > 0 ? ariaLabels : { 'No aria-labels found': '0' };
}

// 日付の時刻をリセットする関数
function resetTime(date) {
  date.setHours(0, 0, 0, 0);  // 時間、分、秒、ミリ秒を 0 にリセット
  return date;
}

function getLastWeekStudyData(ariaLabels, selectedDate) {
  if (!ariaLabels || ariaLabels.length === 0) return { weekData: [], totalTime: 0 };

  // 選択された日付を基準に計算
  const baseDate = resetTime(new Date(selectedDate));
  const oneWeekAgo = new Date(baseDate);
  oneWeekAgo.setDate(baseDate.getDate() - 6);  // 1週間前の日付を計算

  const weekData = [];
  let totalTime = 0;

  for (const label of ariaLabels) {
    const [datePart, timePart] = label.split(' ');
    const [month, day] = datePart.split('/');
    const hours = parseFloat(timePart.replace('時間', ''));

    const labelDate = resetTime(new Date());
    labelDate.setMonth(parseInt(month, 10) - 1);
    labelDate.setDate(parseInt(day, 10));

    // 選択された日付を基準にした1週間以内のデータを集計
    if (labelDate >= oneWeekAgo && labelDate <= baseDate) {
      weekData.push({ date: `${month}/${day}`, hours });
      totalTime += hours;
    }
  }

  return { weekData, totalTime };
}


function formatWeekData(weekData) {
  if (weekData.length === 0) return "一週間分のデータが見つかりませんでした。";

  let result = "";
  for (const entry of weekData) {
    result += `${entry.date}: ${entry.hours}時間\n`;
  }
  return result;
}

document.addEventListener("DOMContentLoaded", function() {
  const selectDate = document.getElementById("selectDate");
  const today = new Date();

  // 直近5日分の日付を追加
  for (let i = 0; i < 3; i++) {
    const date = new Date();
    date.setDate(today.getDate() - i);

    const year = date.getFullYear();
    const month = String(date.getMonth() + 1).padStart(2, '0');
    const day = String(date.getDate()).padStart(2, '0');

    const option = document.createElement("option");
    option.value = `${year}/${month}/${day}`;
    option.text = `${month}/${day}`;
    selectDate.appendChild(option);
  }
});

